/*
 * Copyright 2014-2017 ISP RAS (http://www.ispras.ru)
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

package ru.ispras.testbase;

/**
 * The {@link TestBaseContext} class contains constants that specify attributes
 * of the query context.
 *
 * @author <a href="mailto:andrewt@ispras.ru">Andrei Tatarnikov</a>
 */
public final class TestBaseContext {
  private TestBaseContext() {}

  /**
   * The {@code PROCESSOR} attribute specifies the name of the microprocessor design being tested.
   */
  public static final String PROCESSOR = "processor";

  /**
   * The {@code INSTRUCTION} attribute specifies the name of the instruction for which the test data
   * is to be generated.
   */
  public static final String INSTRUCTION = "instruction";

  /**
   * The {@code TESTCASE} attribute specifies the identifier of the test case for which the test
   * data is to be generated.
   */
  public static final String TESTCASE = "testcase";

  /**
   * The {@code COUNT} attribute specifies the number of times the query is sent to TestBase.
   * This is required when test data for the same instruction are generated in a loop.
   */
  public static final String COUNT = "count";
}
