/*
 * Copyright 2008-2014 ISP RAS (http://www.ispras.ru), UniTESK Lab (http://www.unitesk.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

package ru.ispras.testbase.knowledge.floating.sqrt;

import ru.ispras.testbase.knowledge.basis.GeneratorResult;
import ru.ispras.testbase.knowledge.floating.FpFormat;
import ru.ispras.testbase.knowledge.floating.FpNumber;
import ru.ispras.testbase.knowledge.iterator.FilteringIterator;

/**
 * {@link FpSqrtHardToNRoundIterator} in addition to {@link FpSqrtHardToNRoundInternalIterator}
 * performs filtration of values (removes duplicates).
 *
 * @author <a href="mailto:kamkin@ispras.ru">Alexander Kamkin</a>
 */
public final class FpSqrtHardToNRoundIterator extends FilteringIterator<GeneratorResult<FpNumber>> {
  /** The filter cache size. */
  private static final int FILTER_SIZE = 4;

  /**
   * Constructs a copy of the square root hard-to-round iterator.
   *
   * @param format the format.
   */
  public FpSqrtHardToNRoundIterator(final FpFormat format) {
    super(new FpSqrtHardToDRoundInternalIterator(format), Type.CUSTOM_CHECK, FILTER_SIZE);
    init();
  }

  @Override
  protected boolean equals(
      final GeneratorResult<FpNumber> lhs,
      final GeneratorResult<FpNumber> rhs) {
    return ResultAdapter.equals(lhs, rhs);
  }
}
